Class: Google::Apis::DatafusionV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datafusion_v1/classes.rb,
lib/google/apis/datafusion_v1/representations.rb,
lib/google/apis/datafusion_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



820
821
822
# File 'lib/google/apis/datafusion_v1/classes.rb', line 820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


806
807
808
# File 'lib/google/apis/datafusion_v1/classes.rb', line 806

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DatafusionV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



811
812
813
# File 'lib/google/apis/datafusion_v1/classes.rb', line 811

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections e.g. when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


818
819
820
# File 'lib/google/apis/datafusion_v1/classes.rb', line 818

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



825
826
827
828
829
# File 'lib/google/apis/datafusion_v1/classes.rb', line 825

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end