Class: Google::Apis::DatafusionV1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datafusion_v1/classes.rb,
lib/google/apis/datafusion_v1/representations.rb,
lib/google/apis/datafusion_v1/representations.rb

Overview

Network configuration for a Data Fusion instance. These configurations are used for peering with the customer network. Configurations are optional when a public Data Fusion instance is to be created. However, providing these configurations allows several benefits, such as reduced network latency while accessing the customer resources from managed Data Fusion instance nodes, as well as access to the customer on-prem resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



1040
1041
1042
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_typeString

Optional. Type of connection for establishing private IP connectivity between the Data Fusion customer project VPC and the corresponding tenant project from a predefined list of available connection modes. If this field is unspecified for a private instance, VPC peering is used. Corresponds to the JSON property connectionType

Returns:

  • (String)


1015
1016
1017
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1015

def connection_type
  @connection_type
end

#ip_allocationString

Optional. The IP range in CIDR notation to use for the managed Data Fusion instance nodes. This range must not overlap with any other ranges used in the Data Fusion instance network. This is required only when using connection type VPC_PEERING. Format: a.b.c.d/22 Example: 192.168.0.0/22 Corresponds to the JSON property ipAllocation

Returns:

  • (String)


1023
1024
1025
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1023

def ip_allocation
  @ip_allocation
end

#networkString

Optional. Name of the network in the customer project with which the Tenant Project will be peered for executing pipelines. In case of shared VPC where the network resides in another host project the network should specified in the form of projects/host-project-id/global/networks/network. This is only required for connectivity type VPC_PEERING. Corresponds to the JSON property network

Returns:

  • (String)


1032
1033
1034
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1032

def network
  @network
end

#private_service_connect_configGoogle::Apis::DatafusionV1::PrivateServiceConnectConfig

Configuration for using Private Service Connect to establish connectivity between the Data Fusion consumer project and the corresponding tenant project. Corresponds to the JSON property privateServiceConnectConfig



1038
1039
1040
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1038

def private_service_connect_config
  @private_service_connect_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1045
1046
1047
1048
1049
1050
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1045

def update!(**args)
  @connection_type = args[:connection_type] if args.key?(:connection_type)
  @ip_allocation = args[:ip_allocation] if args.key?(:ip_allocation)
  @network = args[:network] if args.key?(:network)
  @private_service_connect_config = args[:private_service_connect_config] if args.key?(:private_service_connect_config)
end