Class: Google::Apis::DatafusionV1::Version

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datafusion_v1/classes.rb,
lib/google/apis/datafusion_v1/representations.rb,
lib/google/apis/datafusion_v1/representations.rb

Overview

The Data Fusion version. This proto message stores information about certain Data Fusion version, which is used for Data Fusion version upgrade.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Version

Returns a new instance of Version.



1551
1552
1553
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_featuresArray<String>

Represents a list of available feature names for a given version. Corresponds to the JSON property availableFeatures

Returns:

  • (Array<String>)


1533
1534
1535
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1533

def available_features
  @available_features
end

#default_versionBoolean Also known as: default_version?

Whether this is currently the default version for Cloud Data Fusion Corresponds to the JSON property defaultVersion

Returns:

  • (Boolean)


1538
1539
1540
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1538

def default_version
  @default_version
end

#typeString

Type represents the release availability of the version Corresponds to the JSON property type

Returns:

  • (String)


1544
1545
1546
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1544

def type
  @type
end

#version_numberString

The version number of the Data Fusion instance, such as '6.0.1.0'. Corresponds to the JSON property versionNumber

Returns:

  • (String)


1549
1550
1551
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1549

def version_number
  @version_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1556
1557
1558
1559
1560
1561
# File 'lib/google/apis/datafusion_v1/classes.rb', line 1556

def update!(**args)
  @available_features = args[:available_features] if args.key?(:available_features)
  @default_version = args[:default_version] if args.key?(:default_version)
  @type = args[:type] if args.key?(:type)
  @version_number = args[:version_number] if args.key?(:version_number)
end